@@ -50,9 +50,12 @@
 package com.openexchange.admin.rmi.dataobjects;
 
 import java.lang.reflect.Field;
+import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 
 /**
@@ -121,6 +124,8 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
 
     private boolean listrun;
 
+    private List<Object[]> quotas;
+
     public Context() {
         super();
         init();
@@ -151,7 +156,7 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
     }
 
     public final String getIdAsString() {
-        return String.valueOf(this.id);
+        return null == id ? null : id.toString();
     }
 
     @Override
@@ -186,23 +191,36 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
      * Add a single login mapping entry.
      */
     public final void addLoginMapping(final String mapping) {
+        if (null == mapping) {
+            return;
+        }
         if (this.login_mappings == null) {
-            this.login_mappings = new HashSet<String>();
+            this.login_mappings = new HashSet<String>(4);
         }
         this.login_mappings.add(mapping);
     }
 
     public final void addLoginMappings(final Collection<String> mapping) {
+        if (null == mapping) {
+            return;
+        }
         if (this.login_mappings == null) {
-            this.login_mappings = new HashSet<String>();
+            this.login_mappings = new HashSet<String>(4);
+        }
+        for (final String sMapping : mapping) {
+            if (null != sMapping) {
+                this.login_mappings.add(sMapping);
+            }
         }
-        this.login_mappings.addAll(mapping);
     }
 
     /*
      * Remove a login mapping.
      */
     public final boolean removeLoginMapping(final String mapping) {
+        if (null == mapping) {
+            return false;
+        }
         if (null != this.login_mappings) {
             return this.login_mappings.remove(mapping);
         } else {
@@ -211,6 +229,9 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
     }
 
     public final boolean removeLoginMappings(final Collection<String> mapping) {
+        if (null == mapping) {
+            return false;
+        }
         if (null != this.login_mappings) {
             return this.login_mappings.removeAll(mapping);
         } else {
@@ -363,6 +384,7 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
         this.writeDatabase = null;
         this.login_mappings = null;
         this.listrun = false;
+        this.quotas = Collections.emptyList();
     }
 
     /**
@@ -397,6 +419,34 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
         return null;
     }
 
+    /**
+     * Gets the quotas
+     * <pre>
+     *  (["calendar", 1000000L], ["contact", 1000000L], ...)
+     * </pre>
+     *
+     * @return The quotas
+     */
+    public List<Object[]> getQuotas() {
+        return Collections.unmodifiableList(quotas);
+    }
+
+    /**
+     * Sets the quotas
+     * <pre>
+     *  (["calendar", 1000000L], ["contact", 1000000L], ...)
+     * </pre>
+     *
+     * @param quotas The quotas to set
+     */
+    public void setQuotas(List<Object[]> quotas) {
+        if (null == quotas) {
+            this.quotas = Collections.emptyList();
+        } else {
+            this.quotas = new ArrayList<Object[]>(quotas);
+        }
+    }
+
     /**
      * @return the average_sizeset
      */
